==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/content/logistics/packagerLink/LogisticallyLinkedBlockItem.java <==
package com.zurrtum.create.content.logistics.packagerLink;

import com.zurrtum.create.foundation.block.IBE;
import com.zurrtum.create.foundation.blockEntity.behaviour.BlockEntityBehaviour;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.UUID;
import java.util.function.Consumer;
import net.minecraft.class_10712;
import net.minecraft.class_11580;
import net.minecraft.class_124;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_2591;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_4844;
import net.minecraft.class_9334;

public class LogisticallyLinkedBlockItem extends class_1747 {

    public LogisticallyLinkedBlockItem(class_2248 pBlock, class_1793 pProperties) {
        super(pBlock, pProperties);
    }

    @Override
    public boolean method_7886(class_1799 pStack) {
        return isTuned(pStack);
    }

    public static boolean isTuned(class_1799 pStack) {
        return pStack.method_57826(class_9334.field_49611);
    }

    @Nullable
    public static UUID networkFromStack(class_1799 pStack) {
        class_11580<class_2591<?>> data = pStack.method_58694(class_9334.field_49611);
        if (data == null || !data.method_72536("Freq")) {
            return null;
        }
        return data.method_72540().method_67491("Freq", class_4844.field_25122).orElse(null);
    }

    @Override
    @SuppressWarnings("deprecation")
    public void method_67187(
        @NotNull class_1799 stack,
        @NotNull class_9635 tooltipContext,
        class_10712 displayComponent,
        @NotNull Consumer<class_2561> textConsumer,
        class_1836 type
    ) {
        super.method_67187(stack, tooltipContext, displayComponent, textConsumer, type);

        class_11580<class_2591<?>> data = stack.method_58694(class_9334.field_49611);
        if (data == null || !data.method_72536("Freq"))
            return;

        textConsumer.accept(class_2561.method_43471("create.logistically_linked.tooltip").method_27692(class_124.field_1065));

        textConsumer.accept(class_2561.method_43471("create.logistically_linked.tooltip_clear").method_27692(class_124.field_1080));
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 player, class_1268 usedHand) {
        class_1799 stack = player.method_5998(usedHand);
        if (isTuned(stack)) {
            if (world.method_8608()) {
                world.method_8396(player, player.method_24515(), class_3417.field_14770, class_3419.field_15245, 0.75f, 1.0f);
            } else {
                player.method_7353(class_2561.method_43471("create.logistically_linked.cleared"), true);
                stack.method_57381(class_9334.field_49611);
            }
            return class_1269.field_5812;
        } else {
            return super.method_7836(world, player, usedHand);
        }
    }

    @Override
    public @NotNull class_1269 method_7884(class_1838 pContext) {
        class_1799 stack = pContext.method_8041();
        class_2338 pos = pContext.method_8037();
        class_1937 level = pContext.method_8045();
        class_1657 player = pContext.method_8036();

        if (player == null)
            return class_1269.field_5814;
        if (player.method_5715())
            return super.method_7884(pContext);

        LogisticallyLinkedBehaviour link = BlockEntityBehaviour.get(level, pos, LogisticallyLinkedBehaviour.TYPE);
        boolean tuned = isTuned(stack);

        if (link != null) {
            if (level.method_8608())
                return class_1269.field_5812;
            if (!link.mayInteractMessage(player))
                return class_1269.field_5812;

            assignFrequency(stack, player, link.freqId);
            return class_1269.field_5812;
        }

        class_1269 useOn = super.method_7884(pContext);
        if (level.method_8608() || useOn == class_1269.field_5814)
            return useOn;

        player.method_7353(
            tuned ? class_2561.method_43471("create.logistically_linked.connected") : class_2561.method_43471("create.logistically_linked.new_network_started"),
            true
        );
        return useOn;
    }

    public static void assignFrequency(class_1799 stack, class_1657 player, UUID frequency) {
        class_11580<class_2591<?>> data = stack.method_58694(class_9334.field_49611);
        class_2487 tag = data == null ? new class_2487() : data.method_72540();
        tag.method_67494("Freq", class_4844.field_25122, frequency);

        player.method_7353(class_2561.method_43471("create.logistically_linked.tuned"), true);

        stack.method_57379(
            class_9334.field_49611,
            class_11580.method_72535(((IBE<?>) ((class_1747) stack.method_7909()).method_7711()).getBlockEntityType(), tag)
        );
    }

}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/content/logistics/packagerLink/LogisticallyLinkedBlockItem.java <==
package com.zurrtum.create.content.logistics.packagerLink;

import com.zurrtum.create.foundation.block.IBE;
import com.zurrtum.create.foundation.blockEntity.behaviour.BlockEntityBehaviour;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.UUID;
import java.util.function.Consumer;
import net.minecraft.class_10712;
import net.minecraft.class_11580;
import net.minecraft.class_124;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_2591;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_4844;
import net.minecraft.class_9334;

public class LogisticallyLinkedBlockItem extends class_1747 {

    public LogisticallyLinkedBlockItem(class_2248 pBlock, class_1793 pProperties) {
        super(pBlock, pProperties);
    }

    @Override
    public boolean method_7886(class_1799 pStack) {
        return isTuned(pStack);
    }

    public static boolean isTuned(class_1799 pStack) {
        return pStack.method_57826(class_9334.field_49611);
    }

    @Nullable
    public static UUID networkFromStack(class_1799 pStack) {
        class_11580<class_2591<?>> data = pStack.method_58694(class_9334.field_49611);
        if (data == null || !data.method_72536("Freq")) {
            return null;
        }
        return data.method_72540().method_67491("Freq", class_4844.field_25122).orElse(null);
    }

    @Override
    @SuppressWarnings("deprecation")
    public void method_67187(
        @NotNull class_1799 stack,
        @NotNull class_9635 tooltipContext,
        class_10712 displayComponent,
        @NotNull Consumer<class_2561> textConsumer,
        class_1836 type
    ) {
        super.method_67187(stack, tooltipContext, displayComponent, textConsumer, type);

        class_11580<class_2591<?>> data = stack.method_58694(class_9334.field_49611);
        if (data == null || !data.method_72536("Freq"))
            return;

        textConsumer.accept(class_2561.method_43471("create.logistically_linked.tooltip").method_27692(class_124.field_1065));

        textConsumer.accept(class_2561.method_43471("create.logistically_linked.tooltip_clear").method_27692(class_124.field_1080));
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 player, class_1268 usedHand) {
        class_1799 stack = player.method_5998(usedHand);
        if (isTuned(stack)) {
            if (world.method_8608()) {
                world.method_8396(player, player.method_24515(), class_3417.field_14770, class_3419.field_15245, 0.75f, 1.0f);
            } else {
                player.method_7353(class_2561.method_43471("create.logistically_linked.cleared"), true);
                stack.method_57381(class_9334.field_49611);
            }
            return class_1269.field_5812;
        } else {
            return super.method_7836(world, player, usedHand);
        }
    }

    @Override
    public @NotNull class_1269 method_7884(class_1838 pContext) {
        class_1799 stack = pContext.method_8041();
        class_2338 pos = pContext.method_8037();
        class_1937 level = pContext.method_8045();
        class_1657 player = pContext.method_8036();

        if (player == null)
            return class_1269.field_5814;
        if (player.method_5715())
            return super.method_7884(pContext);

        LogisticallyLinkedBehaviour link = BlockEntityBehaviour.get(level, pos, LogisticallyLinkedBehaviour.TYPE);
        boolean tuned = isTuned(stack);

        if (link != null) {
            if (level.method_8608())
                return class_1269.field_5812;
            if (!link.mayInteractMessage(player))
                return class_1269.field_5812;

            assignFrequency(stack, player, link.freqId);
            return class_1269.field_5812;
        }

        class_1269 useOn = super.method_7884(pContext);
        if (level.method_8608() || useOn == class_1269.field_5814)
            return useOn;

        player.method_7353(
            tuned ? class_2561.method_43471("create.logistically_linked.connected") : class_2561.method_43471(
                "create.logistically_linked.new_network_started"), true
        );
        return useOn;
    }

    public static void assignFrequency(class_1799 stack, class_1657 player, UUID frequency) {
        class_11580<class_2591<?>> data = stack.method_58694(class_9334.field_49611);
        class_2487 tag = data == null ? new class_2487() : data.method_72540();
        tag.method_67494("Freq", class_4844.field_25122, frequency);

        player.method_7353(class_2561.method_43471("create.logistically_linked.tuned"), true);

        stack.method_57379(
            class_9334.field_49611,
            class_11580.method_72535(((IBE<?>) ((class_1747) stack.method_7909()).method_7711()).getBlockEntityType(), tag)
        );
    }

}
